pub struct Input {
pub resource: Resource,
pub onlyCertainMatches: Option<FHIRBoolean>,
pub count: Option<FHIRInteger>,
}Fields
resource: ResourceUse this to provide an entire set of patient details for the MPI to match against (e.g. POST a patient record to Patient/$match).
onlyCertainMatches: Option<FHIRBoolean>If there are multiple potential matches, then the match should not return the results with this flag set to true. When false, the server may return multiple results with each result graded accordingly.
count: Option<FHIRInteger>The maximum number of records to return. If no value is provided, the server decides how many matches to return. Note that clients should be careful when using this, as it may prevent probable - and valid - matches from being returned